Setting SuperStrict and declaring the variables reduced my initial 10s to 7s. I aso saved a couple of secs if 'i' was declared as int.
little Benchmark
BlitzMax Forums/BlitzMax Programming/little BenchmarkThe forum is locked. These are the original blitzbasic.com forums, kept so they can still be read. No new topics, replies or edits can be made here. To join in, head over to the Blitz3D+ forums.